# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: onexdataflowapi.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15onexdataflowapi.proto\x12\x0fonexdataflowapi\x1a google/protobuf/descriptor.proto\x1a\x1bgoogle/protobuf/empty.proto\"$\n\rOpenApiMsgOpt\x12\x13\n\x0b\x64\x65scription\x18\n \x01(\t\"5\n\rOpenApiFldOpt\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\n \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x14 \x01(\t\"$\n\rOpenApiSvcOpt\x12\x13\n\x0b\x64\x65scription\x18\n \x01(\t\"$\n\rOpenApiRpcOpt\x12\x13\n\x0b\x64\x65scription\x18\n \x01(\t\"|\n\x11GlobalNamedObject\x12\x39\n\x04name\x18\x01 \x01(\tB&\x92\xa6\x1d\"\xa2\x01\x1fUnique identifier for an objectH\x00\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x07\n\x05_name\"\x85\x01\n\x0c\x45rrorDetails\x12P\n\x06\x65rrors\x18\x01 \x03(\x0b\x32\x1a.onexdataflowapi.ErrorItemB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in models\"\x89\x01\n\x0eWarningDetails\x12R\n\x08warnings\x18\x01 \x03(\x0b\x32\x1a.onexdataflowapi.ErrorItemB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in models\"\x80\x02\n\tErrorItem\x12:\n\x07message\x18\x01 \x01(\tB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12\x37\n\x04\x63ode\x18\x02 \x01(\x05\x42$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x01\x88\x01\x01\x12\x39\n\x06\x64\x65tail\x18\x03 \x01(\tB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x02\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\n\n\x08_messageB\x07\n\x05_codeB\t\n\x07_detail\"\xdc\x01\n\x06\x43onfig\x12J\n\x05hosts\x18\x01 \x03(\x0b\x32\x15.onexdataflowapi.HostB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models\x12V\n\x08\x64\x61taflow\x18\x02 \x01(\x0b\x32\x19.onexdataflowapi.DataflowB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01:!\x8a\xa6\x1d\x1dR\x1bONEx dataflow configurationB\x0b\n\t_dataflow\"4\n\x10GetConfigDetails: \x8a\xa6\x1d\x1cR\x1aGet config request details\"5\n\x11\x45xperimentRequest: \x8a\xa6\x1d\x1cR\x1a\x45xperiment request details\"2\n\x13\x43ontrolStartRequest:\x1b\x8a\xa6\x1d\x17R\x15Start request details\";\n\x14\x43ontrolStatusRequest:#\x8a\xa6\x1d\x1fR\x1d\x63ontrol.state request details\"\xec\x03\n\x15\x43ontrolStatusResponse\x12\xf4\x01\n\x0f\x64\x61taflow_status\x18\x01 \x01(\x0e\x32:.onexdataflowapi.ControlStatusResponse.DataflowStatus.EnumB\x99\x01\x92\xa6\x1d\x94\x01\xa2\x01\x90\x01\x64\x61taflow status:\nstarted - data flow traffic is running\ncompleted - all traffic flows completed, metrics are available\nerror - an error occurredH\x00\x88\x01\x01\x12P\n\x06\x65rrors\x18\x02 \x03(\x0b\x32\x1a.onexdataflowapi.ErrorItemB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models\x1aP\n\x0e\x44\x61taflowStatus\">\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07started\x10\x01\x12\r\n\tcompleted\x10\x02\x12\t\n\x05\x65rror\x10\x03:$\x8a\xa6\x1d R\x1e\x63ontrol/state response detailsB\x12\n\x10_dataflow_status\"/\n\x0eMetricsRequest:\x1d\x8a\xa6\x1d\x19R\x17Metrics request details\"\xe0\x01\n\x0fMetricsResponse\x12=\n\x03jct\x18\x01 \x01(\x03\x42+\x92\xa6\x1d\'\xa2\x01$job completion time in micro secondsH\x00\x88\x01\x01\x12\x66\n\x0c\x66low_results\x18\x02 \x03(\x0b\x32*.onexdataflowapi.MetricsResponseFlowResultB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models:\x1e\x8a\xa6\x1d\x1aR\x18Metrics response detailsB\x06\n\x04_jct\"\xf2\x07\n\x19MetricsResponseFlowResult\x12@\n\rworkload_name\x18\x01 \x01(\tB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12\x41\n\x0e\x66rom_host_name\x18\x02 \x01(\tB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x01\x88\x01\x01\x12?\n\x0cto_host_name\x18\x03 \x01(\tB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x02\x88\x01\x01\x12>\n\x03\x66\x63t\x18\x04 \x01(\x03\x42,\x92\xa6\x1d(\xa2\x01%flow completion time in micro secondsH\x03\x88\x01\x01\x12\x45\n\x0f\x66irst_timestamp\x18\x05 \x01(\x03\x42\'\x92\xa6\x1d#\xa2\x01 first timestamp in micro secondsH\x04\x88\x01\x01\x12\x43\n\x0elast_timestamp\x18\x06 \x01(\x03\x42&\x92\xa6\x1d\"\xa2\x01\x1flast timestamp in micro secondsH\x05\x88\x01\x01\x12?\n\x08\x62ytes_tx\x18\x07 \x01(\x03\x42(\x92\xa6\x1d$\xa2\x01!bytes transmitted from src to dstH\x06\x88\x01\x01\x12<\n\x08\x62ytes_rx\x18\x08 \x01(\x03\x42%\x92\xa6\x1d!\xa2\x01\x1e\x62ytes received by src from dstH\x07\x88\x01\x01\x12x\n\x12tcp_info_initiator\x18\t \x01(\x0b\x32\x31.onexdataflowapi.MetricsResponseFlowResultTcpInfoB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x08\x88\x01\x01\x12x\n\x12tcp_info_responder\x18\n \x01(\x0b\x32\x31.onexdataflowapi.MetricsResponseFlowResultTcpInfoB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\t\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1dresult for a single data flowB\x10\n\x0e_workload_nameB\x11\n\x0f_from_host_nameB\x0f\n\r_to_host_nameB\x06\n\x04_fctB\x12\n\x10_first_timestampB\x11\n\x0f_last_timestampB\x0b\n\t_bytes_txB\x0b\n\t_bytes_rxB\x15\n\x13_tcp_info_initiatorB\x15\n\x13_tcp_info_responder\"\x83\x06\n MetricsResponseFlowResultTcpInfo\x12@\n\x03rtt\x18\x01 \x01(\x03\x42.\x92\xa6\x1d*\xa2\x01\'average round trip time in microsecondsH\x00\x88\x01\x01\x12z\n\x0crtt_variance\x18\x02 \x01(\x03\x42_\x92\xa6\x1d[\xa2\x01Xround trip time variance in microseconds, larger values indicate less stable performanceH\x01\x88\x01\x01\x12H\n\x0fretransmissions\x18\x03 \x01(\x03\x42*\x92\xa6\x1d&\xa2\x01#total number of TCP retransmissionsH\x02\x88\x01\x01\x12S\n\x16retransmission_timeout\x18\x04 \x01(\x03\x42.\x92\xa6\x1d*\xa2\x01\'retransmission timeout in micro secondsH\x03\x88\x01\x01\x12G\n\x11\x63ongestion_window\x18\x05 \x01(\x03\x42\'\x92\xa6\x1d#\xa2\x01 congestion windows size in bytesH\x04\x88\x01\x01\x12h\n\x14slow_start_threshold\x18\x06 \x01(\x03\x42\x45\x92\xa6\x1d\x41\xa2\x01>slow start threshold in bytes (max int64 value when wide open)H\x05\x88\x01\x01\x12&\n\x08path_mtu\x18\x07 \x01(\x03\x42\x0f\x92\xa6\x1d\x0b\xa2\x01\x08path MTUH\x06\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1dTCP information for this flowB\x06\n\x04_rttB\x0f\n\r_rtt_varianceB\x12\n\x10_retransmissionsB\x19\n\x17_retransmission_timeoutB\x14\n\x12_congestion_windowB\x17\n\x15_slow_start_thresholdB\x0b\n\t_path_mtu\"\xa3\x04\n\x04Host\x12<\n\x04name\x18\x01 \x01(\tB.\x92\xa6\x1d*\xa2\x01\'The name, uniquely identifying the host\x12\x34\n\x07\x61\x64\x64ress\x18\x02 \x01(\tB#\x92\xa6\x1d\x1f\xa2\x01\x1cThe test address of the host\x12:\n\x06prefix\x18\x03 \x01(\x05\x42%\x92\xa6\x1d\x04R\x02\x32\x34\x92\xa6\x1d\x19\xa2\x01\x16The prefix of the hostH\x00\x88\x01\x01\x12\xd6\x01\n\x0fl1_profile_name\x18\x04 \x01(\tB\xb7\x01\x92\xa6\x1d\xb2\x01\xa2\x01\xae\x01The layer 1 settings profile associated with the host/front panel port.\n\nx-constraint:\n- ../l1settings/l1_profiles.yaml#/components/schemas/L1SettingsProfile/properties/name\nH\x01\x88\x01\x01\x12>\n\x0b\x61nnotations\x18\x05 \x01(\tB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x02\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\t\n\x07_prefixB\x12\n\x10_l1_profile_nameB\x0e\n\x0c_annotations\"\xcb\x02\n\x08\x44\x61taflow\x12\x66\n\x0fhost_management\x18\x01 \x03(\x0b\x32\'.onexdataflowapi.DataflowHostManagementB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models\x12i\n\x08workload\x18\x02 \x03(\x0b\x32%.onexdataflowapi.DataflowWorkloadItemB0\x92\xa6\x1d,\xa2\x01)The workload items making up the dataflow\x12G\n\rflow_profiles\x18\x03 \x03(\x0b\x32$.onexdataflowapi.DataflowFlowProfileB\n\x92\xa6\x1d\x06\xa2\x01\x03\x66oo:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in models\"\xfd\x07\n\x13\x44\x61taflowFlowProfile\x12\x32\n\x04name\x18\x01 \x01(\tB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models\x12\x37\n\tdata_size\x18\x02 \x01(\x05\x42$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models\x12}\n\x12l2_protocol_choice\x18\x03 \x01(\x0e\x32:.onexdataflowapi.DataflowFlowProfile.L2ProtocolChoice.EnumB \x92\xa6\x1d\x1c\xa2\x01\x19layer2 protocol selectionH\x00\x88\x01\x01\x12i\n\x08\x65thernet\x18\x04 \x01(\x0b\x32,.onexdataflowapi.DataflowFlowProfileEthernetB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x01\x88\x01\x01\x12}\n\x12l4_protocol_choice\x18\x05 \x01(\x0e\x32:.onexdataflowapi.DataflowFlowProfile.L4ProtocolChoice.EnumB \x92\xa6\x1d\x1c\xa2\x01\x19layer4 protocol selectionH\x02\x88\x01\x01\x12]\n\x02ip\x18\x06 \x01(\x0b\x32&.onexdataflowapi.DataflowFlowProfileIpB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x03\x88\x01\x01\x12_\n\x03tcp\x18\x07 \x01(\x0b\x32\'.onexdataflowapi.DataflowFlowProfileTcpB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x04\x88\x01\x01\x12_\n\x03udp\x18\x08 \x01(\x0b\x32\'.onexdataflowapi.DataflowFlowProfileUdpB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x05\x88\x01\x01\x1a\x39\n\x10L2ProtocolChoice\"%\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0c\n\x08\x65thernet\x10\x01\x1a=\n\x10L4ProtocolChoice\")\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03tcp\x10\x01\x12\x07\n\x03udp\x10\x02:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x15\n\x13_l2_protocol_choiceB\x0b\n\t_ethernetB\x15\n\x13_l4_protocol_choiceB\x05\n\x03_ipB\x06\n\x04_tcpB\x06\n\x04_udp\"\x88\x01\n\x1b\x44\x61taflowFlowProfileEthernet\x12<\n\x03mtu\x18\x01 \x01(\x05\x42*\x92\xa6\x1d\x06R\x04\x31\x35\x30\x30\x92\xa6\x1d\x1c\xa2\x01\x19Maximum Transmission UnitH\x00\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x06\n\x04_mtu\"\x83\x01\n\x15\x44\x61taflowFlowProfileIp\x12<\n\x04\x64scp\x18\x01 \x01(\x05\x42)\x92\xa6\x1d%\xa2\x01\"differentiated services code pointH\x00\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x07\n\x05_dscp\"\xd5\n\n\x16\x44\x61taflowFlowProfileTcp\x12\xbe\x02\n\x14\x63ongestion_algorithm\x18\x01 \x01(\x0e\x32@.onexdataflowapi.DataflowFlowProfileTcp.CongestionAlgorithm.EnumB\xd8\x01\x92\xa6\x1d R\x1e\x43ongestionAlgorithm.Enum.cubic\x92\xa6\x1d\xaf\x01\xa2\x01\xab\x01The TCP congestion algorithm:\nbbr - Bottleneck Bandwidth and Round-trip propagation time\ndctcp - Data center TCP\ncubic - cubic window increase function\nreno - TCP New RenoH\x00\x88\x01\x01\x12\x37\n\x08initcwnd\x18\x02 \x01(\x05\x42 \x92\xa6\x1d\x1c\xa2\x01\x19initial congestion windowH\x01\x88\x01\x01\x12.\n\x08send_buf\x18\x03 \x01(\x05\x42\x17\x92\xa6\x1d\x13\xa2\x01\x10send buffer sizeH\x02\x88\x01\x01\x12\x34\n\x0breceive_buf\x18\x04 \x01(\x05\x42\x1a\x92\xa6\x1d\x16\xa2\x01\x13receive buffer sizeH\x03\x88\x01\x01\x12\x37\n\x0b\x64\x65layed_ack\x18\x05 \x01(\x05\x42\x1d\x92\xa6\x1d\x19\xa2\x01\x16\x64\x65layed acknowledgmentH\x04\x88\x01\x01\x12;\n\rselective_ack\x18\x06 \x01(\x08\x42\x1f\x92\xa6\x1d\x1b\xa2\x01\x18selective acknowledgmentH\x05\x88\x01\x01\x12;\n\x07min_rto\x18\x07 \x01(\x05\x42%\x92\xa6\x1d!\xa2\x01\x1eminimum retransmission timeoutH\x06\x88\x01\x01\x12\x37\n\x03mss\x18\x08 \x01(\x05\x42%\x92\xa6\x1d\x06R\x04\x31\x35\x30\x30\x92\xa6\x1d\x17\xa2\x01\x14Maximum Segment SizeH\x07\x88\x01\x01\x12\x36\n\x03\x65\x63n\x18\t \x01(\x08\x42$\x92\xa6\x1d \xa2\x01\x1d\x65\x61rly congestion notificationH\x08\x88\x01\x01\x12=\n\x10\x65nable_timestamp\x18\n \x01(\x08\x42\x1e\x92\xa6\x1d\x1a\xa2\x01\x17\x65nable tcp timestampingH\t\x88\x01\x01\x12\x61\n\x10\x64\x65stination_port\x18\x0b \x01(\x0b\x32\x1c.onexdataflowapi.L4PortRangeB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\n\x88\x01\x01\x12\\\n\x0bsource_port\x18\x0c \x01(\x0b\x32\x1c.onexdataflowapi.L4PortRangeB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x0b\x88\x01\x01\x1aW\n\x13\x43ongestionAlgorithm\"@\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x07\n\x03\x62\x62r\x10\x01\x12\t\n\x05\x64\x63tcp\x10\x02\x12\t\n\x05\x63ubic\x10\x03\x12\x08\n\x04reno\x10\x04:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x17\n\x15_congestion_algorithmB\x0b\n\t_initcwndB\x0b\n\t_send_bufB\x0e\n\x0c_receive_bufB\x0e\n\x0c_delayed_ackB\x10\n\x0e_selective_ackB\n\n\x08_min_rtoB\x06\n\x04_mssB\x06\n\x04_ecnB\x13\n\x11_enable_timestampB\x13\n\x11_destination_portB\x0e\n\x0c_source_port\"\xbf\x03\n\x0bL4PortRange\x12J\n\x06\x63hoice\x18\x01 \x01(\x0e\x32(.onexdataflowapi.L4PortRange.Choice.EnumB\x0b\x92\xa6\x1d\x07\xa2\x01\x04NoneH\x00\x88\x01\x01\x12h\n\x0csingle_value\x18\x02 \x01(\x0b\x32\'.onexdataflowapi.L4PortRangeSingleValueB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x01\x88\x01\x01\x12[\n\x05range\x18\x03 \x01(\x0b\x32!.onexdataflowapi.L4PortRangeRangeB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x02\x88\x01\x01\x1a>\n\x06\x43hoice\"4\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x10\n\x0csingle_value\x10\x01\x12\t\n\x05range\x10\x02:7\x8a\xa6\x1d\x33R1Layer4 protocol source or destination port valuesB\t\n\x07_choiceB\x0f\n\r_single_valueB\x08\n\x06_range\"\x88\x01\n\x16L4PortRangeSingleValue\x12?\n\x05value\x18\x01 \x01(\x05\x42+\x92\xa6\x1d\x03R\x01\x31\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x08\n\x06_value\"\xe1\x01\n\x10L4PortRangeRange\x12\x45\n\x0bstart_value\x18\x01 \x01(\x05\x42+\x92\xa6\x1d\x03R\x01\x31\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12\x43\n\tincrement\x18\x02 \x01(\x05\x42+\x92\xa6\x1d\x03R\x01\x31\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x01\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x0e\n\x0c_start_valueB\x0c\n\n_increment\"=\n\x16\x44\x61taflowFlowProfileUdp:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in models\"\x86\t\n\x14\x44\x61taflowWorkloadItem\x12:\n\x04name\x18\x01 \x01(\tB,\x92\xa6\x1d(\xa2\x01%uniquely identifies the workload item\x12\x63\n\x06\x63hoice\x18\x02 \x01(\x0e\x32\x31.onexdataflowapi.DataflowWorkloadItem.Choice.EnumB \x92\xa6\x1d\x1c\xa2\x01\x19The type of workflow item\x12\x64\n\x07scatter\x18\x03 \x01(\x0b\x32(.onexdataflowapi.DataflowScatterWorkloadB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x00\x88\x01\x01\x12\x62\n\x06gather\x18\x04 \x01(\x0b\x32\'.onexdataflowapi.DataflowGatherWorkloadB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x01\x88\x01\x01\x12^\n\x04loop\x18\x05 \x01(\x0b\x32%.onexdataflowapi.DataflowLoopWorkloadB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x02\x88\x01\x01\x12\x64\n\x07\x63ompute\x18\x06 \x01(\x0b\x32(.onexdataflowapi.DataflowComputeWorkloadB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x03\x88\x01\x01\x12i\n\nall_reduce\x18\x07 \x01(\x0b\x32*.onexdataflowapi.DataflowAllReduceWorkloadB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x04\x88\x01\x01\x12h\n\tbroadcast\x18\x08 \x01(\x0b\x32*.onexdataflowapi.DataflowBroadcastWorkloadB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x05\x88\x01\x01\x12h\n\nall_to_all\x18\t \x01(\x0b\x32).onexdataflowapi.DataflowAlltoallWorkloadB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x06\x88\x01\x01\x1a\x80\x01\n\x06\x43hoice\"v\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x0b\n\x07scatter\x10\x01\x12\n\n\x06gather\x10\x02\x12\x0e\n\nall_reduce\x10\x03\x12\x08\n\x04loop\x10\x04\x12\x0b\n\x07\x63ompute\x10\x05\x12\r\n\tbroadcast\x10\x06\x12\x0e\n\nall_to_all\x10\x07:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\n\n\x08_scatterB\t\n\x07_gatherB\x07\n\x05_loopB\n\n\x08_computeB\r\n\x0b_all_reduceB\x0c\n\n_broadcastB\r\n\x0b_all_to_all\"\xbf\x02\n\x17\x44\x61taflowScatterWorkload\x12Q\n\x07sources\x18\x01 \x03(\tB@\x92\xa6\x1d<\xa2\x01\x39list of host names, indicating the originator of the data\x12W\n\x0c\x64\x65stinations\x18\x02 \x03(\tBA\x92\xa6\x1d=\xa2\x01:list of host names, indicating the destination of the data\x12=\n\x11\x66low_profile_name\x18\x03 \x01(\tB\x1d\x92\xa6\x1d\x19\xa2\x01\x16\x66low profile referenceH\x00\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x14\n\x12_flow_profile_name\"\xc1\x02\n\x19\x44\x61taflowBroadcastWorkload\x12Q\n\x07sources\x18\x01 \x03(\tB@\x92\xa6\x1d<\xa2\x01\x39list of host names, indicating the originator of the data\x12W\n\x0c\x64\x65stinations\x18\x02 \x03(\tBA\x92\xa6\x1d=\xa2\x01:list of host names, indicating the destination of the data\x12=\n\x11\x66low_profile_name\x18\x03 \x01(\tB\x1d\x92\xa6\x1d\x19\xa2\x01\x16\x66low profile referenceH\x00\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x14\n\x12_flow_profile_name\"\xbe\x02\n\x16\x44\x61taflowGatherWorkload\x12Q\n\x07sources\x18\x01 \x03(\tB@\x92\xa6\x1d<\xa2\x01\x39list of host names, indicating the originator of the data\x12W\n\x0c\x64\x65stinations\x18\x02 \x03(\tBA\x92\xa6\x1d=\xa2\x01:list of host names, indicating the destination of the data\x12=\n\x11\x66low_profile_name\x18\x03 \x01(\tB\x1d\x92\xa6\x1d\x19\xa2\x01\x16\x66low profile referenceH\x00\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x14\n\x12_flow_profile_name\"\x8f\x03\n\x19\x44\x61taflowAllReduceWorkload\x12\x33\n\x05nodes\x18\x01 \x03(\tB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models\x12=\n\x11\x66low_profile_name\x18\x02 \x01(\tB\x1d\x92\xa6\x1d\x19\xa2\x01\x16\x66low profile referenceH\x00\x88\x01\x01\x12v\n\x04type\x18\x03 \x01(\x0e\x32\x34.onexdataflowapi.DataflowAllReduceWorkload.Type.EnumB-\x92\xa6\x1d\x10R\x0eType.Enum.ring\x92\xa6\x1d\x15\xa2\x01\x12type of all reduceH\x01\x88\x01\x01\x1a\x42\n\x04Type\":\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\x08\n\x04ring\x10\x01\x12\x08\n\x04tree\x10\x02\x12\r\n\tbutterfly\x10\x03:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x14\n\x12_flow_profile_nameB\x07\n\x05_type\"\xd5\x01\n\x18\x44\x61taflowAlltoallWorkload\x12\x33\n\x05nodes\x18\x01 \x03(\tB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models\x12=\n\x11\x66low_profile_name\x18\x02 \x01(\tB\x1d\x92\xa6\x1d\x19\xa2\x01\x16\x66low profile referenceH\x00\x88\x01\x01:/\x8a\xa6\x1d+R)creates full-mesh flows between all nodesB\x14\n\x12_flow_profile_name\"\x92\x03\n\x17\x44\x61taflowComputeWorkload\x12\x33\n\x05nodes\x18\x01 \x03(\tB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in models\x12\x61\n\x06\x63hoice\x18\x02 \x01(\x0e\x32\x34.onexdataflowapi.DataflowComputeWorkload.Choice.EnumB\x16\x92\xa6\x1d\x12\xa2\x01\x0ftype of computeH\x00\x88\x01\x01\x12o\n\tsimulated\x18\x03 \x01(\x0b\x32\x31.onexdataflowapi.DataflowSimulatedComputeWorkloadB$\x92\xa6\x1d \xa2\x01\x1d\x44\x65scription missing in modelsH\x01\x88\x01\x01\x1a\x30\n\x06\x43hoice\"&\n\x04\x45num\x12\x0f\n\x0bunspecified\x10\x00\x12\r\n\tsimulated\x10\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\t\n\x07_choiceB\x0c\n\n_simulated\"\xa9\x01\n DataflowSimulatedComputeWorkload\x12S\n\x08\x64uration\x18\x01 \x01(\x02\x42<\x92\xa6\x1d\x38\xa2\x01\x35\x64uration of the simulated compute workload in secondsH\x00\x88\x01\x01:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\x0b\n\t_duration\"\x83\x02\n\x14\x44\x61taflowLoopWorkload\x12@\n\niterations\x18\x01 \x01(\x05\x42\'\x92\xa6\x1d#\xa2\x01 number of iterations in the loopH\x00\x88\x01\x01\x12u\n\x08\x63hildren\x18\x02 \x03(\x0b\x32%.onexdataflowapi.DataflowWorkloadItemB<\x92\xa6\x1d\x38\xa2\x01\x35list of workload items that are executed in this loop:#\x8a\xa6\x1d\x1fR\x1d\x44\x65scription missing in modelsB\r\n\x0b_iterations\"\x9a\x03\n\x16\x44\x61taflowHostManagement\x12X\n\thost_name\x18\x01 \x01(\tBE\x92\xa6\x1d\x41\xa2\x01>TBD\n\nx-constraint:\n- #components/schemas/Host/properties/name\n\x12\xc7\x01\n\x14\x65th_nic_profile_name\x18\x02 \x01(\tB\xa3\x01\x92\xa6\x1d\x9e\x01\xa2\x01\x9a\x01The nic parameters profile associated with the host.\n\nx-constraint:\n- #/components/schemas/Profiles.Dataflow.HostManagement.EthNicSetting/properties/name\nH\x00\x88\x01\x01:C\x8a\xa6\x1d?R=auxillary host information needed to run dataflow experimentsB\x17\n\x15_eth_nic_profile_name\";\n\x10SetConfigRequest\x12\'\n\x06\x63onfig\x18\x01 \x01(\x0b\x32\x17.onexdataflowapi.Config\"Q\n\x10GetConfigRequest\x12=\n\x12get_config_details\x18\x01 \x01(\x0b\x32!.onexdataflowapi.GetConfigDetails\"\x80\x02\n\x11SetConfigResponse\x12\x35\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x17.onexdataflowapi.ConfigH\x00\x88\x01\x01\x12;\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x1d.onexdataflowapi.ErrorDetailsH\x01\x88\x01\x01\x12;\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x1d.onexdataflowapi.ErrorDetailsH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"\x80\x02\n\x11GetConfigResponse\x12\x35\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32\x17.onexdataflowapi.ConfigH\x00\x88\x01\x01\x12;\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x1d.onexdataflowapi.ErrorDetailsH\x01\x88\x01\x01\x12;\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x1d.onexdataflowapi.ErrorDetailsH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"V\n\x14RunExperimentRequest\x12>\n\x12\x65xperiment_request\x18\x01 \x01(\x0b\x32\".onexdataflowapi.ExperimentRequest\"\x8c\x02\n\x15RunExperimentResponse\x12;\n\x0fstatus_code_400\x18\x01 \x01(\x0b\x32\x1d.onexdataflowapi.ErrorDetailsH\x00\x88\x01\x01\x12;\n\x0fstatus_code_500\x18\x02 \x01(\x0b\x32\x1d.onexdataflowapi.ErrorDetailsH\x01\x88\x01\x01\x12=\n\x0fstatus_code_200\x18\x03 \x01(\x0b\x32\x1f.onexdataflowapi.WarningDetailsH\x02\x88\x01\x01\x42\x12\n\x10_status_code_400B\x12\n\x10_status_code_500B\x12\n\x10_status_code_200\"S\n\x0cStartRequest\x12\x43\n\x15\x63ontrol_start_request\x18\x01 \x01(\x0b\x32$.onexdataflowapi.ControlStartRequest\"\x84\x02\n\rStartResponse\x12;\n\x0fstatus_code_400\x18\x01 \x01(\x0b\x32\x1d.onexdataflowapi.ErrorDetailsH\x00\x88\x01\x01\x12;\n\x0fstatus_code_500\x18\x02 \x01(\x0b\x32\x1d.onexdataflowapi.ErrorDetailsH\x01\x88\x01\x01\x12=\n\x0fstatus_code_200\x18\x03 \x01(\x0b\x32\x1f.onexdataflowapi.WarningDetailsH\x02\x88\x01\x01\x42\x12\n\x10_status_code_400B\x12\n\x10_status_code_500B\x12\n\x10_status_code_200\"Y\n\x10GetStatusRequest\x12\x45\n\x16\x63ontrol_status_request\x18\x01 \x01(\x0b\x32%.onexdataflowapi.ControlStatusRequest\"\x8f\x02\n\x11GetStatusResponse\x12\x44\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32&.onexdataflowapi.ControlStatusResponseH\x00\x88\x01\x01\x12;\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x1d.onexdataflowapi.ErrorDetailsH\x01\x88\x01\x01\x12;\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x1d.onexdataflowapi.ErrorDetailsH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_500\"M\n\x11GetMetricsRequest\x12\x38\n\x0fmetrics_request\x18\x01 \x01(\x0b\x32\x1f.onexdataflowapi.MetricsRequest\"\x8a\x02\n\x12GetMetricsResponse\x12>\n\x0fstatus_code_200\x18\x01 \x01(\x0b\x32 .onexdataflowapi.MetricsResponseH\x00\x88\x01\x01\x12;\n\x0fstatus_code_400\x18\x02 \x01(\x0b\x32\x1d.onexdataflowapi.ErrorDetailsH\x01\x88\x01\x01\x12;\n\x0fstatus_code_500\x18\x03 \x01(\x0b\x32\x1d.onexdataflowapi.ErrorDetailsH\x02\x88\x01\x01\x42\x12\n\x10_status_code_200B\x12\n\x10_status_code_400B\x12\n\x10_status_code_5002\xfe\x06\n\x07Openapi\x12~\n\tSetConfig\x12!.onexdataflowapi.SetConfigRequest\x1a\".onexdataflowapi.SetConfigResponse\"*\xa2\xa6\x1d&R$Sets the ONEx dataflow configuration\x12\xa0\x01\n\tGetConfig\x12!.onexdataflowapi.GetConfigRequest\x1a\".onexdataflowapi.GetConfigResponse\"L\xa2\xa6\x1dHRFGets the ONEx dataflow config from the server, as currently configured\x12\x97\x01\n\rRunExperiment\x12%.onexdataflowapi.RunExperimentRequest\x1a&.onexdataflowapi.RunExperimentResponse\"7\xa2\xa6\x1d\x33R1Runs the currently configured dataflow experiment\x12\x81\x01\n\x05Start\x12\x1d.onexdataflowapi.StartRequest\x1a\x1e.onexdataflowapi.StartResponse\"9\xa2\xa6\x1d\x35R3Starts the currently configured dataflow experiment\x12\x90\x01\n\tGetStatus\x12!.onexdataflowapi.GetStatusRequest\x1a\".onexdataflowapi.GetStatusResponse\"<\xa2\xa6\x1d\x38R6Gets the control status (e.g. started/completed/error)\x12z\n\nGetMetrics\x12\".onexdataflowapi.GetMetricsRequest\x1a#.onexdataflowapi.GetMetricsResponse\"#\xa2\xa6\x1d\x1fR\x1d\x44\x65scription missing in models\x1a#\x9a\xa6\x1d\x1fR\x1d\x44\x65scription missing in models:V\n\x08msg_meta\x12\x1f.google.protobuf.MessageOptions\x18\xe1\xd4\x03 \x01(\x0b\x32\x1e.onexdataflowapi.OpenApiMsgOpt\x88\x01\x01:T\n\x08\x66ld_meta\x12\x1d.google.protobuf.FieldOptions\x18\xe2\xd4\x03 \x01(\x0b\x32\x1e.onexdataflowapi.OpenApiFldOpt\x88\x01\x01:V\n\x08svc_meta\x12\x1f.google.protobuf.ServiceOptions\x18\xe3\xd4\x03 \x01(\x0b\x32\x1e.onexdataflowapi.OpenApiSvcOpt\x88\x01\x01:U\n\x08rpc_meta\x12\x1e.google.protobuf.MethodOptions\x18\xe4\xd4\x03 \x01(\x0b\x32\x1e.onexdataflowapi.OpenApiRpcOpt\x88\x01\x01\x62\x06proto3')


MSG_META_FIELD_NUMBER = 60001
msg_meta = DESCRIPTOR.extensions_by_name['msg_meta']
FLD_META_FIELD_NUMBER = 60002
fld_meta = DESCRIPTOR.extensions_by_name['fld_meta']
SVC_META_FIELD_NUMBER = 60003
svc_meta = DESCRIPTOR.extensions_by_name['svc_meta']
RPC_META_FIELD_NUMBER = 60004
rpc_meta = DESCRIPTOR.extensions_by_name['rpc_meta']

_OPENAPIMSGOPT = DESCRIPTOR.message_types_by_name['OpenApiMsgOpt']
_OPENAPIFLDOPT = DESCRIPTOR.message_types_by_name['OpenApiFldOpt']
_OPENAPISVCOPT = DESCRIPTOR.message_types_by_name['OpenApiSvcOpt']
_OPENAPIRPCOPT = DESCRIPTOR.message_types_by_name['OpenApiRpcOpt']
_GLOBALNAMEDOBJECT = DESCRIPTOR.message_types_by_name['GlobalNamedObject']
_ERRORDETAILS = DESCRIPTOR.message_types_by_name['ErrorDetails']
_WARNINGDETAILS = DESCRIPTOR.message_types_by_name['WarningDetails']
_ERRORITEM = DESCRIPTOR.message_types_by_name['ErrorItem']
_CONFIG = DESCRIPTOR.message_types_by_name['Config']
_GETCONFIGDETAILS = DESCRIPTOR.message_types_by_name['GetConfigDetails']
_EXPERIMENTREQUEST = DESCRIPTOR.message_types_by_name['ExperimentRequest']
_CONTROLSTARTREQUEST = DESCRIPTOR.message_types_by_name['ControlStartRequest']
_CONTROLSTATUSREQUEST = DESCRIPTOR.message_types_by_name['ControlStatusRequest']
_CONTROLSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['ControlStatusResponse']
_CONTROLSTATUSRESPONSE_DATAFLOWSTATUS = _CONTROLSTATUSRESPONSE.nested_types_by_name['DataflowStatus']
_METRICSREQUEST = DESCRIPTOR.message_types_by_name['MetricsRequest']
_METRICSRESPONSE = DESCRIPTOR.message_types_by_name['MetricsResponse']
_METRICSRESPONSEFLOWRESULT = DESCRIPTOR.message_types_by_name['MetricsResponseFlowResult']
_METRICSRESPONSEFLOWRESULTTCPINFO = DESCRIPTOR.message_types_by_name['MetricsResponseFlowResultTcpInfo']
_HOST = DESCRIPTOR.message_types_by_name['Host']
_DATAFLOW = DESCRIPTOR.message_types_by_name['Dataflow']
_DATAFLOWFLOWPROFILE = DESCRIPTOR.message_types_by_name['DataflowFlowProfile']
_DATAFLOWFLOWPROFILE_L2PROTOCOLCHOICE = _DATAFLOWFLOWPROFILE.nested_types_by_name['L2ProtocolChoice']
_DATAFLOWFLOWPROFILE_L4PROTOCOLCHOICE = _DATAFLOWFLOWPROFILE.nested_types_by_name['L4ProtocolChoice']
_DATAFLOWFLOWPROFILEETHERNET = DESCRIPTOR.message_types_by_name['DataflowFlowProfileEthernet']
_DATAFLOWFLOWPROFILEIP = DESCRIPTOR.message_types_by_name['DataflowFlowProfileIp']
_DATAFLOWFLOWPROFILETCP = DESCRIPTOR.message_types_by_name['DataflowFlowProfileTcp']
_DATAFLOWFLOWPROFILETCP_CONGESTIONALGORITHM = _DATAFLOWFLOWPROFILETCP.nested_types_by_name['CongestionAlgorithm']
_L4PORTRANGE = DESCRIPTOR.message_types_by_name['L4PortRange']
_L4PORTRANGE_CHOICE = _L4PORTRANGE.nested_types_by_name['Choice']
_L4PORTRANGESINGLEVALUE = DESCRIPTOR.message_types_by_name['L4PortRangeSingleValue']
_L4PORTRANGERANGE = DESCRIPTOR.message_types_by_name['L4PortRangeRange']
_DATAFLOWFLOWPROFILEUDP = DESCRIPTOR.message_types_by_name['DataflowFlowProfileUdp']
_DATAFLOWWORKLOADITEM = DESCRIPTOR.message_types_by_name['DataflowWorkloadItem']
_DATAFLOWWORKLOADITEM_CHOICE = _DATAFLOWWORKLOADITEM.nested_types_by_name['Choice']
_DATAFLOWSCATTERWORKLOAD = DESCRIPTOR.message_types_by_name['DataflowScatterWorkload']
_DATAFLOWBROADCASTWORKLOAD = DESCRIPTOR.message_types_by_name['DataflowBroadcastWorkload']
_DATAFLOWGATHERWORKLOAD = DESCRIPTOR.message_types_by_name['DataflowGatherWorkload']
_DATAFLOWALLREDUCEWORKLOAD = DESCRIPTOR.message_types_by_name['DataflowAllReduceWorkload']
_DATAFLOWALLREDUCEWORKLOAD_TYPE = _DATAFLOWALLREDUCEWORKLOAD.nested_types_by_name['Type']
_DATAFLOWALLTOALLWORKLOAD = DESCRIPTOR.message_types_by_name['DataflowAlltoallWorkload']
_DATAFLOWCOMPUTEWORKLOAD = DESCRIPTOR.message_types_by_name['DataflowComputeWorkload']
_DATAFLOWCOMPUTEWORKLOAD_CHOICE = _DATAFLOWCOMPUTEWORKLOAD.nested_types_by_name['Choice']
_DATAFLOWSIMULATEDCOMPUTEWORKLOAD = DESCRIPTOR.message_types_by_name['DataflowSimulatedComputeWorkload']
_DATAFLOWLOOPWORKLOAD = DESCRIPTOR.message_types_by_name['DataflowLoopWorkload']
_DATAFLOWHOSTMANAGEMENT = DESCRIPTOR.message_types_by_name['DataflowHostManagement']
_SETCONFIGREQUEST = DESCRIPTOR.message_types_by_name['SetConfigRequest']
_GETCONFIGREQUEST = DESCRIPTOR.message_types_by_name['GetConfigRequest']
_SETCONFIGRESPONSE = DESCRIPTOR.message_types_by_name['SetConfigResponse']
_GETCONFIGRESPONSE = DESCRIPTOR.message_types_by_name['GetConfigResponse']
_RUNEXPERIMENTREQUEST = DESCRIPTOR.message_types_by_name['RunExperimentRequest']
_RUNEXPERIMENTRESPONSE = DESCRIPTOR.message_types_by_name['RunExperimentResponse']
_STARTREQUEST = DESCRIPTOR.message_types_by_name['StartRequest']
_STARTRESPONSE = DESCRIPTOR.message_types_by_name['StartResponse']
_GETSTATUSREQUEST = DESCRIPTOR.message_types_by_name['GetStatusRequest']
_GETSTATUSRESPONSE = DESCRIPTOR.message_types_by_name['GetStatusResponse']
_GETMETRICSREQUEST = DESCRIPTOR.message_types_by_name['GetMetricsRequest']
_GETMETRICSRESPONSE = DESCRIPTOR.message_types_by_name['GetMetricsResponse']
_CONTROLSTATUSRESPONSE_DATAFLOWSTATUS_ENUM = _CONTROLSTATUSRESPONSE_DATAFLOWSTATUS.enum_types_by_name['Enum']
_DATAFLOWFLOWPROFILE_L2PROTOCOLCHOICE_ENUM = _DATAFLOWFLOWPROFILE_L2PROTOCOLCHOICE.enum_types_by_name['Enum']
_DATAFLOWFLOWPROFILE_L4PROTOCOLCHOICE_ENUM = _DATAFLOWFLOWPROFILE_L4PROTOCOLCHOICE.enum_types_by_name['Enum']
_DATAFLOWFLOWPROFILETCP_CONGESTIONALGORITHM_ENUM = _DATAFLOWFLOWPROFILETCP_CONGESTIONALGORITHM.enum_types_by_name['Enum']
_L4PORTRANGE_CHOICE_ENUM = _L4PORTRANGE_CHOICE.enum_types_by_name['Enum']
_DATAFLOWWORKLOADITEM_CHOICE_ENUM = _DATAFLOWWORKLOADITEM_CHOICE.enum_types_by_name['Enum']
_DATAFLOWALLREDUCEWORKLOAD_TYPE_ENUM = _DATAFLOWALLREDUCEWORKLOAD_TYPE.enum_types_by_name['Enum']
_DATAFLOWCOMPUTEWORKLOAD_CHOICE_ENUM = _DATAFLOWCOMPUTEWORKLOAD_CHOICE.enum_types_by_name['Enum']
OpenApiMsgOpt = _reflection.GeneratedProtocolMessageType('OpenApiMsgOpt', (_message.Message,), {
  'DESCRIPTOR' : _OPENAPIMSGOPT,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.OpenApiMsgOpt)
  })
_sym_db.RegisterMessage(OpenApiMsgOpt)

OpenApiFldOpt = _reflection.GeneratedProtocolMessageType('OpenApiFldOpt', (_message.Message,), {
  'DESCRIPTOR' : _OPENAPIFLDOPT,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.OpenApiFldOpt)
  })
_sym_db.RegisterMessage(OpenApiFldOpt)

OpenApiSvcOpt = _reflection.GeneratedProtocolMessageType('OpenApiSvcOpt', (_message.Message,), {
  'DESCRIPTOR' : _OPENAPISVCOPT,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.OpenApiSvcOpt)
  })
_sym_db.RegisterMessage(OpenApiSvcOpt)

OpenApiRpcOpt = _reflection.GeneratedProtocolMessageType('OpenApiRpcOpt', (_message.Message,), {
  'DESCRIPTOR' : _OPENAPIRPCOPT,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.OpenApiRpcOpt)
  })
_sym_db.RegisterMessage(OpenApiRpcOpt)

GlobalNamedObject = _reflection.GeneratedProtocolMessageType('GlobalNamedObject', (_message.Message,), {
  'DESCRIPTOR' : _GLOBALNAMEDOBJECT,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.GlobalNamedObject)
  })
_sym_db.RegisterMessage(GlobalNamedObject)

ErrorDetails = _reflection.GeneratedProtocolMessageType('ErrorDetails', (_message.Message,), {
  'DESCRIPTOR' : _ERRORDETAILS,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.ErrorDetails)
  })
_sym_db.RegisterMessage(ErrorDetails)

WarningDetails = _reflection.GeneratedProtocolMessageType('WarningDetails', (_message.Message,), {
  'DESCRIPTOR' : _WARNINGDETAILS,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.WarningDetails)
  })
_sym_db.RegisterMessage(WarningDetails)

ErrorItem = _reflection.GeneratedProtocolMessageType('ErrorItem', (_message.Message,), {
  'DESCRIPTOR' : _ERRORITEM,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.ErrorItem)
  })
_sym_db.RegisterMessage(ErrorItem)

Config = _reflection.GeneratedProtocolMessageType('Config', (_message.Message,), {
  'DESCRIPTOR' : _CONFIG,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.Config)
  })
_sym_db.RegisterMessage(Config)

GetConfigDetails = _reflection.GeneratedProtocolMessageType('GetConfigDetails', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGDETAILS,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.GetConfigDetails)
  })
_sym_db.RegisterMessage(GetConfigDetails)

ExperimentRequest = _reflection.GeneratedProtocolMessageType('ExperimentRequest', (_message.Message,), {
  'DESCRIPTOR' : _EXPERIMENTREQUEST,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.ExperimentRequest)
  })
_sym_db.RegisterMessage(ExperimentRequest)

ControlStartRequest = _reflection.GeneratedProtocolMessageType('ControlStartRequest', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLSTARTREQUEST,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.ControlStartRequest)
  })
_sym_db.RegisterMessage(ControlStartRequest)

ControlStatusRequest = _reflection.GeneratedProtocolMessageType('ControlStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _CONTROLSTATUSREQUEST,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.ControlStatusRequest)
  })
_sym_db.RegisterMessage(ControlStatusRequest)

ControlStatusResponse = _reflection.GeneratedProtocolMessageType('ControlStatusResponse', (_message.Message,), {

  'DataflowStatus' : _reflection.GeneratedProtocolMessageType('DataflowStatus', (_message.Message,), {
    'DESCRIPTOR' : _CONTROLSTATUSRESPONSE_DATAFLOWSTATUS,
    '__module__' : 'onexdataflowapi_pb2'
    # @@protoc_insertion_point(class_scope:onexdataflowapi.ControlStatusResponse.DataflowStatus)
    })
  ,
  'DESCRIPTOR' : _CONTROLSTATUSRESPONSE,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.ControlStatusResponse)
  })
_sym_db.RegisterMessage(ControlStatusResponse)
_sym_db.RegisterMessage(ControlStatusResponse.DataflowStatus)

MetricsRequest = _reflection.GeneratedProtocolMessageType('MetricsRequest', (_message.Message,), {
  'DESCRIPTOR' : _METRICSREQUEST,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.MetricsRequest)
  })
_sym_db.RegisterMessage(MetricsRequest)

MetricsResponse = _reflection.GeneratedProtocolMessageType('MetricsResponse', (_message.Message,), {
  'DESCRIPTOR' : _METRICSRESPONSE,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.MetricsResponse)
  })
_sym_db.RegisterMessage(MetricsResponse)

MetricsResponseFlowResult = _reflection.GeneratedProtocolMessageType('MetricsResponseFlowResult', (_message.Message,), {
  'DESCRIPTOR' : _METRICSRESPONSEFLOWRESULT,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.MetricsResponseFlowResult)
  })
_sym_db.RegisterMessage(MetricsResponseFlowResult)

MetricsResponseFlowResultTcpInfo = _reflection.GeneratedProtocolMessageType('MetricsResponseFlowResultTcpInfo', (_message.Message,), {
  'DESCRIPTOR' : _METRICSRESPONSEFLOWRESULTTCPINFO,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.MetricsResponseFlowResultTcpInfo)
  })
_sym_db.RegisterMessage(MetricsResponseFlowResultTcpInfo)

Host = _reflection.GeneratedProtocolMessageType('Host', (_message.Message,), {
  'DESCRIPTOR' : _HOST,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.Host)
  })
_sym_db.RegisterMessage(Host)

Dataflow = _reflection.GeneratedProtocolMessageType('Dataflow', (_message.Message,), {
  'DESCRIPTOR' : _DATAFLOW,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.Dataflow)
  })
_sym_db.RegisterMessage(Dataflow)

DataflowFlowProfile = _reflection.GeneratedProtocolMessageType('DataflowFlowProfile', (_message.Message,), {

  'L2ProtocolChoice' : _reflection.GeneratedProtocolMessageType('L2ProtocolChoice', (_message.Message,), {
    'DESCRIPTOR' : _DATAFLOWFLOWPROFILE_L2PROTOCOLCHOICE,
    '__module__' : 'onexdataflowapi_pb2'
    # @@protoc_insertion_point(class_scope:onexdataflowapi.DataflowFlowProfile.L2ProtocolChoice)
    })
  ,

  'L4ProtocolChoice' : _reflection.GeneratedProtocolMessageType('L4ProtocolChoice', (_message.Message,), {
    'DESCRIPTOR' : _DATAFLOWFLOWPROFILE_L4PROTOCOLCHOICE,
    '__module__' : 'onexdataflowapi_pb2'
    # @@protoc_insertion_point(class_scope:onexdataflowapi.DataflowFlowProfile.L4ProtocolChoice)
    })
  ,
  'DESCRIPTOR' : _DATAFLOWFLOWPROFILE,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.DataflowFlowProfile)
  })
_sym_db.RegisterMessage(DataflowFlowProfile)
_sym_db.RegisterMessage(DataflowFlowProfile.L2ProtocolChoice)
_sym_db.RegisterMessage(DataflowFlowProfile.L4ProtocolChoice)

DataflowFlowProfileEthernet = _reflection.GeneratedProtocolMessageType('DataflowFlowProfileEthernet', (_message.Message,), {
  'DESCRIPTOR' : _DATAFLOWFLOWPROFILEETHERNET,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.DataflowFlowProfileEthernet)
  })
_sym_db.RegisterMessage(DataflowFlowProfileEthernet)

DataflowFlowProfileIp = _reflection.GeneratedProtocolMessageType('DataflowFlowProfileIp', (_message.Message,), {
  'DESCRIPTOR' : _DATAFLOWFLOWPROFILEIP,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.DataflowFlowProfileIp)
  })
_sym_db.RegisterMessage(DataflowFlowProfileIp)

DataflowFlowProfileTcp = _reflection.GeneratedProtocolMessageType('DataflowFlowProfileTcp', (_message.Message,), {

  'CongestionAlgorithm' : _reflection.GeneratedProtocolMessageType('CongestionAlgorithm', (_message.Message,), {
    'DESCRIPTOR' : _DATAFLOWFLOWPROFILETCP_CONGESTIONALGORITHM,
    '__module__' : 'onexdataflowapi_pb2'
    # @@protoc_insertion_point(class_scope:onexdataflowapi.DataflowFlowProfileTcp.CongestionAlgorithm)
    })
  ,
  'DESCRIPTOR' : _DATAFLOWFLOWPROFILETCP,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.DataflowFlowProfileTcp)
  })
_sym_db.RegisterMessage(DataflowFlowProfileTcp)
_sym_db.RegisterMessage(DataflowFlowProfileTcp.CongestionAlgorithm)

L4PortRange = _reflection.GeneratedProtocolMessageType('L4PortRange', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _L4PORTRANGE_CHOICE,
    '__module__' : 'onexdataflowapi_pb2'
    # @@protoc_insertion_point(class_scope:onexdataflowapi.L4PortRange.Choice)
    })
  ,
  'DESCRIPTOR' : _L4PORTRANGE,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.L4PortRange)
  })
_sym_db.RegisterMessage(L4PortRange)
_sym_db.RegisterMessage(L4PortRange.Choice)

L4PortRangeSingleValue = _reflection.GeneratedProtocolMessageType('L4PortRangeSingleValue', (_message.Message,), {
  'DESCRIPTOR' : _L4PORTRANGESINGLEVALUE,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.L4PortRangeSingleValue)
  })
_sym_db.RegisterMessage(L4PortRangeSingleValue)

L4PortRangeRange = _reflection.GeneratedProtocolMessageType('L4PortRangeRange', (_message.Message,), {
  'DESCRIPTOR' : _L4PORTRANGERANGE,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.L4PortRangeRange)
  })
_sym_db.RegisterMessage(L4PortRangeRange)

DataflowFlowProfileUdp = _reflection.GeneratedProtocolMessageType('DataflowFlowProfileUdp', (_message.Message,), {
  'DESCRIPTOR' : _DATAFLOWFLOWPROFILEUDP,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.DataflowFlowProfileUdp)
  })
_sym_db.RegisterMessage(DataflowFlowProfileUdp)

DataflowWorkloadItem = _reflection.GeneratedProtocolMessageType('DataflowWorkloadItem', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _DATAFLOWWORKLOADITEM_CHOICE,
    '__module__' : 'onexdataflowapi_pb2'
    # @@protoc_insertion_point(class_scope:onexdataflowapi.DataflowWorkloadItem.Choice)
    })
  ,
  'DESCRIPTOR' : _DATAFLOWWORKLOADITEM,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.DataflowWorkloadItem)
  })
_sym_db.RegisterMessage(DataflowWorkloadItem)
_sym_db.RegisterMessage(DataflowWorkloadItem.Choice)

DataflowScatterWorkload = _reflection.GeneratedProtocolMessageType('DataflowScatterWorkload', (_message.Message,), {
  'DESCRIPTOR' : _DATAFLOWSCATTERWORKLOAD,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.DataflowScatterWorkload)
  })
_sym_db.RegisterMessage(DataflowScatterWorkload)

DataflowBroadcastWorkload = _reflection.GeneratedProtocolMessageType('DataflowBroadcastWorkload', (_message.Message,), {
  'DESCRIPTOR' : _DATAFLOWBROADCASTWORKLOAD,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.DataflowBroadcastWorkload)
  })
_sym_db.RegisterMessage(DataflowBroadcastWorkload)

DataflowGatherWorkload = _reflection.GeneratedProtocolMessageType('DataflowGatherWorkload', (_message.Message,), {
  'DESCRIPTOR' : _DATAFLOWGATHERWORKLOAD,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.DataflowGatherWorkload)
  })
_sym_db.RegisterMessage(DataflowGatherWorkload)

DataflowAllReduceWorkload = _reflection.GeneratedProtocolMessageType('DataflowAllReduceWorkload', (_message.Message,), {

  'Type' : _reflection.GeneratedProtocolMessageType('Type', (_message.Message,), {
    'DESCRIPTOR' : _DATAFLOWALLREDUCEWORKLOAD_TYPE,
    '__module__' : 'onexdataflowapi_pb2'
    # @@protoc_insertion_point(class_scope:onexdataflowapi.DataflowAllReduceWorkload.Type)
    })
  ,
  'DESCRIPTOR' : _DATAFLOWALLREDUCEWORKLOAD,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.DataflowAllReduceWorkload)
  })
_sym_db.RegisterMessage(DataflowAllReduceWorkload)
_sym_db.RegisterMessage(DataflowAllReduceWorkload.Type)

DataflowAlltoallWorkload = _reflection.GeneratedProtocolMessageType('DataflowAlltoallWorkload', (_message.Message,), {
  'DESCRIPTOR' : _DATAFLOWALLTOALLWORKLOAD,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.DataflowAlltoallWorkload)
  })
_sym_db.RegisterMessage(DataflowAlltoallWorkload)

DataflowComputeWorkload = _reflection.GeneratedProtocolMessageType('DataflowComputeWorkload', (_message.Message,), {

  'Choice' : _reflection.GeneratedProtocolMessageType('Choice', (_message.Message,), {
    'DESCRIPTOR' : _DATAFLOWCOMPUTEWORKLOAD_CHOICE,
    '__module__' : 'onexdataflowapi_pb2'
    # @@protoc_insertion_point(class_scope:onexdataflowapi.DataflowComputeWorkload.Choice)
    })
  ,
  'DESCRIPTOR' : _DATAFLOWCOMPUTEWORKLOAD,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.DataflowComputeWorkload)
  })
_sym_db.RegisterMessage(DataflowComputeWorkload)
_sym_db.RegisterMessage(DataflowComputeWorkload.Choice)

DataflowSimulatedComputeWorkload = _reflection.GeneratedProtocolMessageType('DataflowSimulatedComputeWorkload', (_message.Message,), {
  'DESCRIPTOR' : _DATAFLOWSIMULATEDCOMPUTEWORKLOAD,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.DataflowSimulatedComputeWorkload)
  })
_sym_db.RegisterMessage(DataflowSimulatedComputeWorkload)

DataflowLoopWorkload = _reflection.GeneratedProtocolMessageType('DataflowLoopWorkload', (_message.Message,), {
  'DESCRIPTOR' : _DATAFLOWLOOPWORKLOAD,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.DataflowLoopWorkload)
  })
_sym_db.RegisterMessage(DataflowLoopWorkload)

DataflowHostManagement = _reflection.GeneratedProtocolMessageType('DataflowHostManagement', (_message.Message,), {
  'DESCRIPTOR' : _DATAFLOWHOSTMANAGEMENT,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.DataflowHostManagement)
  })
_sym_db.RegisterMessage(DataflowHostManagement)

SetConfigRequest = _reflection.GeneratedProtocolMessageType('SetConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGREQUEST,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.SetConfigRequest)
  })
_sym_db.RegisterMessage(SetConfigRequest)

GetConfigRequest = _reflection.GeneratedProtocolMessageType('GetConfigRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGREQUEST,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.GetConfigRequest)
  })
_sym_db.RegisterMessage(GetConfigRequest)

SetConfigResponse = _reflection.GeneratedProtocolMessageType('SetConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETCONFIGRESPONSE,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.SetConfigResponse)
  })
_sym_db.RegisterMessage(SetConfigResponse)

GetConfigResponse = _reflection.GeneratedProtocolMessageType('GetConfigResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETCONFIGRESPONSE,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.GetConfigResponse)
  })
_sym_db.RegisterMessage(GetConfigResponse)

RunExperimentRequest = _reflection.GeneratedProtocolMessageType('RunExperimentRequest', (_message.Message,), {
  'DESCRIPTOR' : _RUNEXPERIMENTREQUEST,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.RunExperimentRequest)
  })
_sym_db.RegisterMessage(RunExperimentRequest)

RunExperimentResponse = _reflection.GeneratedProtocolMessageType('RunExperimentResponse', (_message.Message,), {
  'DESCRIPTOR' : _RUNEXPERIMENTRESPONSE,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.RunExperimentResponse)
  })
_sym_db.RegisterMessage(RunExperimentResponse)

StartRequest = _reflection.GeneratedProtocolMessageType('StartRequest', (_message.Message,), {
  'DESCRIPTOR' : _STARTREQUEST,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.StartRequest)
  })
_sym_db.RegisterMessage(StartRequest)

StartResponse = _reflection.GeneratedProtocolMessageType('StartResponse', (_message.Message,), {
  'DESCRIPTOR' : _STARTRESPONSE,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.StartResponse)
  })
_sym_db.RegisterMessage(StartResponse)

GetStatusRequest = _reflection.GeneratedProtocolMessageType('GetStatusRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATUSREQUEST,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.GetStatusRequest)
  })
_sym_db.RegisterMessage(GetStatusRequest)

GetStatusResponse = _reflection.GeneratedProtocolMessageType('GetStatusResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETSTATUSRESPONSE,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.GetStatusResponse)
  })
_sym_db.RegisterMessage(GetStatusResponse)

GetMetricsRequest = _reflection.GeneratedProtocolMessageType('GetMetricsRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETMETRICSREQUEST,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.GetMetricsRequest)
  })
_sym_db.RegisterMessage(GetMetricsRequest)

GetMetricsResponse = _reflection.GeneratedProtocolMessageType('GetMetricsResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETMETRICSRESPONSE,
  '__module__' : 'onexdataflowapi_pb2'
  # @@protoc_insertion_point(class_scope:onexdataflowapi.GetMetricsResponse)
  })
_sym_db.RegisterMessage(GetMetricsResponse)

_OPENAPI = DESCRIPTOR.services_by_name['Openapi']
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(msg_meta)
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(fld_meta)
  google_dot_protobuf_dot_descriptor__pb2.ServiceOptions.RegisterExtension(svc_meta)
  google_dot_protobuf_dot_descriptor__pb2.MethodOptions.RegisterExtension(rpc_meta)

  DESCRIPTOR._options = None
  _GLOBALNAMEDOBJECT.fields_by_name['name']._options = None
  _GLOBALNAMEDOBJECT.fields_by_name['name']._serialized_options = b'\222\246\035\"\242\001\037Unique identifier for an object'
  _GLOBALNAMEDOBJECT._options = None
  _GLOBALNAMEDOBJECT._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _ERRORDETAILS.fields_by_name['errors']._options = None
  _ERRORDETAILS.fields_by_name['errors']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _ERRORDETAILS._options = None
  _ERRORDETAILS._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _WARNINGDETAILS.fields_by_name['warnings']._options = None
  _WARNINGDETAILS.fields_by_name['warnings']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _WARNINGDETAILS._options = None
  _WARNINGDETAILS._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _ERRORITEM.fields_by_name['message']._options = None
  _ERRORITEM.fields_by_name['message']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _ERRORITEM.fields_by_name['code']._options = None
  _ERRORITEM.fields_by_name['code']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _ERRORITEM.fields_by_name['detail']._options = None
  _ERRORITEM.fields_by_name['detail']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _ERRORITEM._options = None
  _ERRORITEM._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _CONFIG.fields_by_name['hosts']._options = None
  _CONFIG.fields_by_name['hosts']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _CONFIG.fields_by_name['dataflow']._options = None
  _CONFIG.fields_by_name['dataflow']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _CONFIG._options = None
  _CONFIG._serialized_options = b'\212\246\035\035R\033ONEx dataflow configuration'
  _GETCONFIGDETAILS._options = None
  _GETCONFIGDETAILS._serialized_options = b'\212\246\035\034R\032Get config request details'
  _EXPERIMENTREQUEST._options = None
  _EXPERIMENTREQUEST._serialized_options = b'\212\246\035\034R\032Experiment request details'
  _CONTROLSTARTREQUEST._options = None
  _CONTROLSTARTREQUEST._serialized_options = b'\212\246\035\027R\025Start request details'
  _CONTROLSTATUSREQUEST._options = None
  _CONTROLSTATUSREQUEST._serialized_options = b'\212\246\035\037R\035control.state request details'
  _CONTROLSTATUSRESPONSE.fields_by_name['dataflow_status']._options = None
  _CONTROLSTATUSRESPONSE.fields_by_name['dataflow_status']._serialized_options = b'\222\246\035\224\001\242\001\220\001dataflow status:\nstarted - data flow traffic is running\ncompleted - all traffic flows completed, metrics are available\nerror - an error occurred'
  _CONTROLSTATUSRESPONSE.fields_by_name['errors']._options = None
  _CONTROLSTATUSRESPONSE.fields_by_name['errors']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _CONTROLSTATUSRESPONSE._options = None
  _CONTROLSTATUSRESPONSE._serialized_options = b'\212\246\035 R\036control/state response details'
  _METRICSREQUEST._options = None
  _METRICSREQUEST._serialized_options = b'\212\246\035\031R\027Metrics request details'
  _METRICSRESPONSE.fields_by_name['jct']._options = None
  _METRICSRESPONSE.fields_by_name['jct']._serialized_options = b'\222\246\035\'\242\001$job completion time in micro seconds'
  _METRICSRESPONSE.fields_by_name['flow_results']._options = None
  _METRICSRESPONSE.fields_by_name['flow_results']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _METRICSRESPONSE._options = None
  _METRICSRESPONSE._serialized_options = b'\212\246\035\032R\030Metrics response details'
  _METRICSRESPONSEFLOWRESULT.fields_by_name['workload_name']._options = None
  _METRICSRESPONSEFLOWRESULT.fields_by_name['workload_name']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _METRICSRESPONSEFLOWRESULT.fields_by_name['from_host_name']._options = None
  _METRICSRESPONSEFLOWRESULT.fields_by_name['from_host_name']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _METRICSRESPONSEFLOWRESULT.fields_by_name['to_host_name']._options = None
  _METRICSRESPONSEFLOWRESULT.fields_by_name['to_host_name']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _METRICSRESPONSEFLOWRESULT.fields_by_name['fct']._options = None
  _METRICSRESPONSEFLOWRESULT.fields_by_name['fct']._serialized_options = b'\222\246\035(\242\001%flow completion time in micro seconds'
  _METRICSRESPONSEFLOWRESULT.fields_by_name['first_timestamp']._options = None
  _METRICSRESPONSEFLOWRESULT.fields_by_name['first_timestamp']._serialized_options = b'\222\246\035#\242\001 first timestamp in micro seconds'
  _METRICSRESPONSEFLOWRESULT.fields_by_name['last_timestamp']._options = None
  _METRICSRESPONSEFLOWRESULT.fields_by_name['last_timestamp']._serialized_options = b'\222\246\035\"\242\001\037last timestamp in micro seconds'
  _METRICSRESPONSEFLOWRESULT.fields_by_name['bytes_tx']._options = None
  _METRICSRESPONSEFLOWRESULT.fields_by_name['bytes_tx']._serialized_options = b'\222\246\035$\242\001!bytes transmitted from src to dst'
  _METRICSRESPONSEFLOWRESULT.fields_by_name['bytes_rx']._options = None
  _METRICSRESPONSEFLOWRESULT.fields_by_name['bytes_rx']._serialized_options = b'\222\246\035!\242\001\036bytes received by src from dst'
  _METRICSRESPONSEFLOWRESULT.fields_by_name['tcp_info_initiator']._options = None
  _METRICSRESPONSEFLOWRESULT.fields_by_name['tcp_info_initiator']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _METRICSRESPONSEFLOWRESULT.fields_by_name['tcp_info_responder']._options = None
  _METRICSRESPONSEFLOWRESULT.fields_by_name['tcp_info_responder']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _METRICSRESPONSEFLOWRESULT._options = None
  _METRICSRESPONSEFLOWRESULT._serialized_options = b'\212\246\035\037R\035result for a single data flow'
  _METRICSRESPONSEFLOWRESULTTCPINFO.fields_by_name['rtt']._options = None
  _METRICSRESPONSEFLOWRESULTTCPINFO.fields_by_name['rtt']._serialized_options = b'\222\246\035*\242\001\'average round trip time in microseconds'
  _METRICSRESPONSEFLOWRESULTTCPINFO.fields_by_name['rtt_variance']._options = None
  _METRICSRESPONSEFLOWRESULTTCPINFO.fields_by_name['rtt_variance']._serialized_options = b'\222\246\035[\242\001Xround trip time variance in microseconds, larger values indicate less stable performance'
  _METRICSRESPONSEFLOWRESULTTCPINFO.fields_by_name['retransmissions']._options = None
  _METRICSRESPONSEFLOWRESULTTCPINFO.fields_by_name['retransmissions']._serialized_options = b'\222\246\035&\242\001#total number of TCP retransmissions'
  _METRICSRESPONSEFLOWRESULTTCPINFO.fields_by_name['retransmission_timeout']._options = None
  _METRICSRESPONSEFLOWRESULTTCPINFO.fields_by_name['retransmission_timeout']._serialized_options = b'\222\246\035*\242\001\'retransmission timeout in micro seconds'
  _METRICSRESPONSEFLOWRESULTTCPINFO.fields_by_name['congestion_window']._options = None
  _METRICSRESPONSEFLOWRESULTTCPINFO.fields_by_name['congestion_window']._serialized_options = b'\222\246\035#\242\001 congestion windows size in bytes'
  _METRICSRESPONSEFLOWRESULTTCPINFO.fields_by_name['slow_start_threshold']._options = None
  _METRICSRESPONSEFLOWRESULTTCPINFO.fields_by_name['slow_start_threshold']._serialized_options = b'\222\246\035A\242\001>slow start threshold in bytes (max int64 value when wide open)'
  _METRICSRESPONSEFLOWRESULTTCPINFO.fields_by_name['path_mtu']._options = None
  _METRICSRESPONSEFLOWRESULTTCPINFO.fields_by_name['path_mtu']._serialized_options = b'\222\246\035\013\242\001\010path MTU'
  _METRICSRESPONSEFLOWRESULTTCPINFO._options = None
  _METRICSRESPONSEFLOWRESULTTCPINFO._serialized_options = b'\212\246\035\037R\035TCP information for this flow'
  _HOST.fields_by_name['name']._options = None
  _HOST.fields_by_name['name']._serialized_options = b'\222\246\035*\242\001\'The name, uniquely identifying the host'
  _HOST.fields_by_name['address']._options = None
  _HOST.fields_by_name['address']._serialized_options = b'\222\246\035\037\242\001\034The test address of the host'
  _HOST.fields_by_name['prefix']._options = None
  _HOST.fields_by_name['prefix']._serialized_options = b'\222\246\035\004R\00224\222\246\035\031\242\001\026The prefix of the host'
  _HOST.fields_by_name['l1_profile_name']._options = None
  _HOST.fields_by_name['l1_profile_name']._serialized_options = b'\222\246\035\262\001\242\001\256\001The layer 1 settings profile associated with the host/front panel port.\n\nx-constraint:\n- ../l1settings/l1_profiles.yaml#/components/schemas/L1SettingsProfile/properties/name\n'
  _HOST.fields_by_name['annotations']._options = None
  _HOST.fields_by_name['annotations']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _HOST._options = None
  _HOST._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _DATAFLOW.fields_by_name['host_management']._options = None
  _DATAFLOW.fields_by_name['host_management']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _DATAFLOW.fields_by_name['workload']._options = None
  _DATAFLOW.fields_by_name['workload']._serialized_options = b'\222\246\035,\242\001)The workload items making up the dataflow'
  _DATAFLOW.fields_by_name['flow_profiles']._options = None
  _DATAFLOW.fields_by_name['flow_profiles']._serialized_options = b'\222\246\035\006\242\001\003foo'
  _DATAFLOW._options = None
  _DATAFLOW._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _DATAFLOWFLOWPROFILE.fields_by_name['name']._options = None
  _DATAFLOWFLOWPROFILE.fields_by_name['name']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _DATAFLOWFLOWPROFILE.fields_by_name['data_size']._options = None
  _DATAFLOWFLOWPROFILE.fields_by_name['data_size']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _DATAFLOWFLOWPROFILE.fields_by_name['l2_protocol_choice']._options = None
  _DATAFLOWFLOWPROFILE.fields_by_name['l2_protocol_choice']._serialized_options = b'\222\246\035\034\242\001\031layer2 protocol selection'
  _DATAFLOWFLOWPROFILE.fields_by_name['ethernet']._options = None
  _DATAFLOWFLOWPROFILE.fields_by_name['ethernet']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _DATAFLOWFLOWPROFILE.fields_by_name['l4_protocol_choice']._options = None
  _DATAFLOWFLOWPROFILE.fields_by_name['l4_protocol_choice']._serialized_options = b'\222\246\035\034\242\001\031layer4 protocol selection'
  _DATAFLOWFLOWPROFILE.fields_by_name['ip']._options = None
  _DATAFLOWFLOWPROFILE.fields_by_name['ip']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _DATAFLOWFLOWPROFILE.fields_by_name['tcp']._options = None
  _DATAFLOWFLOWPROFILE.fields_by_name['tcp']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _DATAFLOWFLOWPROFILE.fields_by_name['udp']._options = None
  _DATAFLOWFLOWPROFILE.fields_by_name['udp']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _DATAFLOWFLOWPROFILE._options = None
  _DATAFLOWFLOWPROFILE._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _DATAFLOWFLOWPROFILEETHERNET.fields_by_name['mtu']._options = None
  _DATAFLOWFLOWPROFILEETHERNET.fields_by_name['mtu']._serialized_options = b'\222\246\035\006R\0041500\222\246\035\034\242\001\031Maximum Transmission Unit'
  _DATAFLOWFLOWPROFILEETHERNET._options = None
  _DATAFLOWFLOWPROFILEETHERNET._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _DATAFLOWFLOWPROFILEIP.fields_by_name['dscp']._options = None
  _DATAFLOWFLOWPROFILEIP.fields_by_name['dscp']._serialized_options = b'\222\246\035%\242\001\"differentiated services code point'
  _DATAFLOWFLOWPROFILEIP._options = None
  _DATAFLOWFLOWPROFILEIP._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _DATAFLOWFLOWPROFILETCP.fields_by_name['congestion_algorithm']._options = None
  _DATAFLOWFLOWPROFILETCP.fields_by_name['congestion_algorithm']._serialized_options = b'\222\246\035 R\036CongestionAlgorithm.Enum.cubic\222\246\035\257\001\242\001\253\001The TCP congestion algorithm:\nbbr - Bottleneck Bandwidth and Round-trip propagation time\ndctcp - Data center TCP\ncubic - cubic window increase function\nreno - TCP New Reno'
  _DATAFLOWFLOWPROFILETCP.fields_by_name['initcwnd']._options = None
  _DATAFLOWFLOWPROFILETCP.fields_by_name['initcwnd']._serialized_options = b'\222\246\035\034\242\001\031initial congestion window'
  _DATAFLOWFLOWPROFILETCP.fields_by_name['send_buf']._options = None
  _DATAFLOWFLOWPROFILETCP.fields_by_name['send_buf']._serialized_options = b'\222\246\035\023\242\001\020send buffer size'
  _DATAFLOWFLOWPROFILETCP.fields_by_name['receive_buf']._options = None
  _DATAFLOWFLOWPROFILETCP.fields_by_name['receive_buf']._serialized_options = b'\222\246\035\026\242\001\023receive buffer size'
  _DATAFLOWFLOWPROFILETCP.fields_by_name['delayed_ack']._options = None
  _DATAFLOWFLOWPROFILETCP.fields_by_name['delayed_ack']._serialized_options = b'\222\246\035\031\242\001\026delayed acknowledgment'
  _DATAFLOWFLOWPROFILETCP.fields_by_name['selective_ack']._options = None
  _DATAFLOWFLOWPROFILETCP.fields_by_name['selective_ack']._serialized_options = b'\222\246\035\033\242\001\030selective acknowledgment'
  _DATAFLOWFLOWPROFILETCP.fields_by_name['min_rto']._options = None
  _DATAFLOWFLOWPROFILETCP.fields_by_name['min_rto']._serialized_options = b'\222\246\035!\242\001\036minimum retransmission timeout'
  _DATAFLOWFLOWPROFILETCP.fields_by_name['mss']._options = None
  _DATAFLOWFLOWPROFILETCP.fields_by_name['mss']._serialized_options = b'\222\246\035\006R\0041500\222\246\035\027\242\001\024Maximum Segment Size'
  _DATAFLOWFLOWPROFILETCP.fields_by_name['ecn']._options = None
  _DATAFLOWFLOWPROFILETCP.fields_by_name['ecn']._serialized_options = b'\222\246\035 \242\001\035early congestion notification'
  _DATAFLOWFLOWPROFILETCP.fields_by_name['enable_timestamp']._options = None
  _DATAFLOWFLOWPROFILETCP.fields_by_name['enable_timestamp']._serialized_options = b'\222\246\035\032\242\001\027enable tcp timestamping'
  _DATAFLOWFLOWPROFILETCP.fields_by_name['destination_port']._options = None
  _DATAFLOWFLOWPROFILETCP.fields_by_name['destination_port']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _DATAFLOWFLOWPROFILETCP.fields_by_name['source_port']._options = None
  _DATAFLOWFLOWPROFILETCP.fields_by_name['source_port']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _DATAFLOWFLOWPROFILETCP._options = None
  _DATAFLOWFLOWPROFILETCP._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _L4PORTRANGE.fields_by_name['choice']._options = None
  _L4PORTRANGE.fields_by_name['choice']._serialized_options = b'\222\246\035\007\242\001\004None'
  _L4PORTRANGE.fields_by_name['single_value']._options = None
  _L4PORTRANGE.fields_by_name['single_value']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _L4PORTRANGE.fields_by_name['range']._options = None
  _L4PORTRANGE.fields_by_name['range']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _L4PORTRANGE._options = None
  _L4PORTRANGE._serialized_options = b'\212\246\0353R1Layer4 protocol source or destination port values'
  _L4PORTRANGESINGLEVALUE.fields_by_name['value']._options = None
  _L4PORTRANGESINGLEVALUE.fields_by_name['value']._serialized_options = b'\222\246\035\003R\0011\222\246\035 \242\001\035Description missing in models'
  _L4PORTRANGESINGLEVALUE._options = None
  _L4PORTRANGESINGLEVALUE._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _L4PORTRANGERANGE.fields_by_name['start_value']._options = None
  _L4PORTRANGERANGE.fields_by_name['start_value']._serialized_options = b'\222\246\035\003R\0011\222\246\035 \242\001\035Description missing in models'
  _L4PORTRANGERANGE.fields_by_name['increment']._options = None
  _L4PORTRANGERANGE.fields_by_name['increment']._serialized_options = b'\222\246\035\003R\0011\222\246\035 \242\001\035Description missing in models'
  _L4PORTRANGERANGE._options = None
  _L4PORTRANGERANGE._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _DATAFLOWFLOWPROFILEUDP._options = None
  _DATAFLOWFLOWPROFILEUDP._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _DATAFLOWWORKLOADITEM.fields_by_name['name']._options = None
  _DATAFLOWWORKLOADITEM.fields_by_name['name']._serialized_options = b'\222\246\035(\242\001%uniquely identifies the workload item'
  _DATAFLOWWORKLOADITEM.fields_by_name['choice']._options = None
  _DATAFLOWWORKLOADITEM.fields_by_name['choice']._serialized_options = b'\222\246\035\034\242\001\031The type of workflow item'
  _DATAFLOWWORKLOADITEM.fields_by_name['scatter']._options = None
  _DATAFLOWWORKLOADITEM.fields_by_name['scatter']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _DATAFLOWWORKLOADITEM.fields_by_name['gather']._options = None
  _DATAFLOWWORKLOADITEM.fields_by_name['gather']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _DATAFLOWWORKLOADITEM.fields_by_name['loop']._options = None
  _DATAFLOWWORKLOADITEM.fields_by_name['loop']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _DATAFLOWWORKLOADITEM.fields_by_name['compute']._options = None
  _DATAFLOWWORKLOADITEM.fields_by_name['compute']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _DATAFLOWWORKLOADITEM.fields_by_name['all_reduce']._options = None
  _DATAFLOWWORKLOADITEM.fields_by_name['all_reduce']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _DATAFLOWWORKLOADITEM.fields_by_name['broadcast']._options = None
  _DATAFLOWWORKLOADITEM.fields_by_name['broadcast']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _DATAFLOWWORKLOADITEM.fields_by_name['all_to_all']._options = None
  _DATAFLOWWORKLOADITEM.fields_by_name['all_to_all']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _DATAFLOWWORKLOADITEM._options = None
  _DATAFLOWWORKLOADITEM._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _DATAFLOWSCATTERWORKLOAD.fields_by_name['sources']._options = None
  _DATAFLOWSCATTERWORKLOAD.fields_by_name['sources']._serialized_options = b'\222\246\035<\242\0019list of host names, indicating the originator of the data'
  _DATAFLOWSCATTERWORKLOAD.fields_by_name['destinations']._options = None
  _DATAFLOWSCATTERWORKLOAD.fields_by_name['destinations']._serialized_options = b'\222\246\035=\242\001:list of host names, indicating the destination of the data'
  _DATAFLOWSCATTERWORKLOAD.fields_by_name['flow_profile_name']._options = None
  _DATAFLOWSCATTERWORKLOAD.fields_by_name['flow_profile_name']._serialized_options = b'\222\246\035\031\242\001\026flow profile reference'
  _DATAFLOWSCATTERWORKLOAD._options = None
  _DATAFLOWSCATTERWORKLOAD._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _DATAFLOWBROADCASTWORKLOAD.fields_by_name['sources']._options = None
  _DATAFLOWBROADCASTWORKLOAD.fields_by_name['sources']._serialized_options = b'\222\246\035<\242\0019list of host names, indicating the originator of the data'
  _DATAFLOWBROADCASTWORKLOAD.fields_by_name['destinations']._options = None
  _DATAFLOWBROADCASTWORKLOAD.fields_by_name['destinations']._serialized_options = b'\222\246\035=\242\001:list of host names, indicating the destination of the data'
  _DATAFLOWBROADCASTWORKLOAD.fields_by_name['flow_profile_name']._options = None
  _DATAFLOWBROADCASTWORKLOAD.fields_by_name['flow_profile_name']._serialized_options = b'\222\246\035\031\242\001\026flow profile reference'
  _DATAFLOWBROADCASTWORKLOAD._options = None
  _DATAFLOWBROADCASTWORKLOAD._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _DATAFLOWGATHERWORKLOAD.fields_by_name['sources']._options = None
  _DATAFLOWGATHERWORKLOAD.fields_by_name['sources']._serialized_options = b'\222\246\035<\242\0019list of host names, indicating the originator of the data'
  _DATAFLOWGATHERWORKLOAD.fields_by_name['destinations']._options = None
  _DATAFLOWGATHERWORKLOAD.fields_by_name['destinations']._serialized_options = b'\222\246\035=\242\001:list of host names, indicating the destination of the data'
  _DATAFLOWGATHERWORKLOAD.fields_by_name['flow_profile_name']._options = None
  _DATAFLOWGATHERWORKLOAD.fields_by_name['flow_profile_name']._serialized_options = b'\222\246\035\031\242\001\026flow profile reference'
  _DATAFLOWGATHERWORKLOAD._options = None
  _DATAFLOWGATHERWORKLOAD._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _DATAFLOWALLREDUCEWORKLOAD.fields_by_name['nodes']._options = None
  _DATAFLOWALLREDUCEWORKLOAD.fields_by_name['nodes']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _DATAFLOWALLREDUCEWORKLOAD.fields_by_name['flow_profile_name']._options = None
  _DATAFLOWALLREDUCEWORKLOAD.fields_by_name['flow_profile_name']._serialized_options = b'\222\246\035\031\242\001\026flow profile reference'
  _DATAFLOWALLREDUCEWORKLOAD.fields_by_name['type']._options = None
  _DATAFLOWALLREDUCEWORKLOAD.fields_by_name['type']._serialized_options = b'\222\246\035\020R\016Type.Enum.ring\222\246\035\025\242\001\022type of all reduce'
  _DATAFLOWALLREDUCEWORKLOAD._options = None
  _DATAFLOWALLREDUCEWORKLOAD._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _DATAFLOWALLTOALLWORKLOAD.fields_by_name['nodes']._options = None
  _DATAFLOWALLTOALLWORKLOAD.fields_by_name['nodes']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _DATAFLOWALLTOALLWORKLOAD.fields_by_name['flow_profile_name']._options = None
  _DATAFLOWALLTOALLWORKLOAD.fields_by_name['flow_profile_name']._serialized_options = b'\222\246\035\031\242\001\026flow profile reference'
  _DATAFLOWALLTOALLWORKLOAD._options = None
  _DATAFLOWALLTOALLWORKLOAD._serialized_options = b'\212\246\035+R)creates full-mesh flows between all nodes'
  _DATAFLOWCOMPUTEWORKLOAD.fields_by_name['nodes']._options = None
  _DATAFLOWCOMPUTEWORKLOAD.fields_by_name['nodes']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _DATAFLOWCOMPUTEWORKLOAD.fields_by_name['choice']._options = None
  _DATAFLOWCOMPUTEWORKLOAD.fields_by_name['choice']._serialized_options = b'\222\246\035\022\242\001\017type of compute'
  _DATAFLOWCOMPUTEWORKLOAD.fields_by_name['simulated']._options = None
  _DATAFLOWCOMPUTEWORKLOAD.fields_by_name['simulated']._serialized_options = b'\222\246\035 \242\001\035Description missing in models'
  _DATAFLOWCOMPUTEWORKLOAD._options = None
  _DATAFLOWCOMPUTEWORKLOAD._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _DATAFLOWSIMULATEDCOMPUTEWORKLOAD.fields_by_name['duration']._options = None
  _DATAFLOWSIMULATEDCOMPUTEWORKLOAD.fields_by_name['duration']._serialized_options = b'\222\246\0358\242\0015duration of the simulated compute workload in seconds'
  _DATAFLOWSIMULATEDCOMPUTEWORKLOAD._options = None
  _DATAFLOWSIMULATEDCOMPUTEWORKLOAD._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _DATAFLOWLOOPWORKLOAD.fields_by_name['iterations']._options = None
  _DATAFLOWLOOPWORKLOAD.fields_by_name['iterations']._serialized_options = b'\222\246\035#\242\001 number of iterations in the loop'
  _DATAFLOWLOOPWORKLOAD.fields_by_name['children']._options = None
  _DATAFLOWLOOPWORKLOAD.fields_by_name['children']._serialized_options = b'\222\246\0358\242\0015list of workload items that are executed in this loop'
  _DATAFLOWLOOPWORKLOAD._options = None
  _DATAFLOWLOOPWORKLOAD._serialized_options = b'\212\246\035\037R\035Description missing in models'
  _DATAFLOWHOSTMANAGEMENT.fields_by_name['host_name']._options = None
  _DATAFLOWHOSTMANAGEMENT.fields_by_name['host_name']._serialized_options = b'\222\246\035A\242\001>TBD\n\nx-constraint:\n- #components/schemas/Host/properties/name\n'
  _DATAFLOWHOSTMANAGEMENT.fields_by_name['eth_nic_profile_name']._options = None
  _DATAFLOWHOSTMANAGEMENT.fields_by_name['eth_nic_profile_name']._serialized_options = b'\222\246\035\236\001\242\001\232\001The nic parameters profile associated with the host.\n\nx-constraint:\n- #/components/schemas/Profiles.Dataflow.HostManagement.EthNicSetting/properties/name\n'
  _DATAFLOWHOSTMANAGEMENT._options = None
  _DATAFLOWHOSTMANAGEMENT._serialized_options = b'\212\246\035?R=auxillary host information needed to run dataflow experiments'
  _OPENAPI._options = None
  _OPENAPI._serialized_options = b'\232\246\035\037R\035Description missing in models'
  _OPENAPI.methods_by_name['SetConfig']._options = None
  _OPENAPI.methods_by_name['SetConfig']._serialized_options = b'\242\246\035&R$Sets the ONEx dataflow configuration'
  _OPENAPI.methods_by_name['GetConfig']._options = None
  _OPENAPI.methods_by_name['GetConfig']._serialized_options = b'\242\246\035HRFGets the ONEx dataflow config from the server, as currently configured'
  _OPENAPI.methods_by_name['RunExperiment']._options = None
  _OPENAPI.methods_by_name['RunExperiment']._serialized_options = b'\242\246\0353R1Runs the currently configured dataflow experiment'
  _OPENAPI.methods_by_name['Start']._options = None
  _OPENAPI.methods_by_name['Start']._serialized_options = b'\242\246\0355R3Starts the currently configured dataflow experiment'
  _OPENAPI.methods_by_name['GetStatus']._options = None
  _OPENAPI.methods_by_name['GetStatus']._serialized_options = b'\242\246\0358R6Gets the control status (e.g. started/completed/error)'
  _OPENAPI.methods_by_name['GetMetrics']._options = None
  _OPENAPI.methods_by_name['GetMetrics']._serialized_options = b'\242\246\035\037R\035Description missing in models'
  _OPENAPIMSGOPT._serialized_start=105
  _OPENAPIMSGOPT._serialized_end=141
  _OPENAPIFLDOPT._serialized_start=143
  _OPENAPIFLDOPT._serialized_end=196
  _OPENAPISVCOPT._serialized_start=198
  _OPENAPISVCOPT._serialized_end=234
  _OPENAPIRPCOPT._serialized_start=236
  _OPENAPIRPCOPT._serialized_end=272
  _GLOBALNAMEDOBJECT._serialized_start=274
  _GLOBALNAMEDOBJECT._serialized_end=398
  _ERRORDETAILS._serialized_start=401
  _ERRORDETAILS._serialized_end=534
  _WARNINGDETAILS._serialized_start=537
  _WARNINGDETAILS._serialized_end=674
  _ERRORITEM._serialized_start=677
  _ERRORITEM._serialized_end=933
  _CONFIG._serialized_start=936
  _CONFIG._serialized_end=1156
  _GETCONFIGDETAILS._serialized_start=1158
  _GETCONFIGDETAILS._serialized_end=1210
  _EXPERIMENTREQUEST._serialized_start=1212
  _EXPERIMENTREQUEST._serialized_end=1265
  _CONTROLSTARTREQUEST._serialized_start=1267
  _CONTROLSTARTREQUEST._serialized_end=1317
  _CONTROLSTATUSREQUEST._serialized_start=1319
  _CONTROLSTATUSREQUEST._serialized_end=1378
  _CONTROLSTATUSRESPONSE._serialized_start=1381
  _CONTROLSTATUSRESPONSE._serialized_end=1873
  _CONTROLSTATUSRESPONSE_DATAFLOWSTATUS._serialized_start=1735
  _CONTROLSTATUSRESPONSE_DATAFLOWSTATUS._serialized_end=1815
  _CONTROLSTATUSRESPONSE_DATAFLOWSTATUS_ENUM._serialized_start=1753
  _CONTROLSTATUSRESPONSE_DATAFLOWSTATUS_ENUM._serialized_end=1815
  _METRICSREQUEST._serialized_start=1875
  _METRICSREQUEST._serialized_end=1922
  _METRICSRESPONSE._serialized_start=1925
  _METRICSRESPONSE._serialized_end=2149
  _METRICSRESPONSEFLOWRESULT._serialized_start=2152
  _METRICSRESPONSEFLOWRESULT._serialized_end=3162
  _METRICSRESPONSEFLOWRESULTTCPINFO._serialized_start=3165
  _METRICSRESPONSEFLOWRESULTTCPINFO._serialized_end=3936
  _HOST._serialized_start=3939
  _HOST._serialized_end=4486
  _DATAFLOW._serialized_start=4489
  _DATAFLOW._serialized_end=4820
  _DATAFLOWFLOWPROFILE._serialized_start=4823
  _DATAFLOWFLOWPROFILE._serialized_end=5844
  _DATAFLOWFLOWPROFILE_L2PROTOCOLCHOICE._serialized_start=5605
  _DATAFLOWFLOWPROFILE_L2PROTOCOLCHOICE._serialized_end=5662
  _DATAFLOWFLOWPROFILE_L2PROTOCOLCHOICE_ENUM._serialized_start=5625
  _DATAFLOWFLOWPROFILE_L2PROTOCOLCHOICE_ENUM._serialized_end=5662
  _DATAFLOWFLOWPROFILE_L4PROTOCOLCHOICE._serialized_start=5664
  _DATAFLOWFLOWPROFILE_L4PROTOCOLCHOICE._serialized_end=5725
  _DATAFLOWFLOWPROFILE_L4PROTOCOLCHOICE_ENUM._serialized_start=5684
  _DATAFLOWFLOWPROFILE_L4PROTOCOLCHOICE_ENUM._serialized_end=5725
  _DATAFLOWFLOWPROFILEETHERNET._serialized_start=5847
  _DATAFLOWFLOWPROFILEETHERNET._serialized_end=5983
  _DATAFLOWFLOWPROFILEIP._serialized_start=5986
  _DATAFLOWFLOWPROFILEIP._serialized_end=6117
  _DATAFLOWFLOWPROFILETCP._serialized_start=6120
  _DATAFLOWFLOWPROFILETCP._serialized_end=7485
  _DATAFLOWFLOWPROFILETCP_CONGESTIONALGORITHM._serialized_start=7174
  _DATAFLOWFLOWPROFILETCP_CONGESTIONALGORITHM._serialized_end=7261
  _DATAFLOWFLOWPROFILETCP_CONGESTIONALGORITHM_ENUM._serialized_start=7197
  _DATAFLOWFLOWPROFILETCP_CONGESTIONALGORITHM_ENUM._serialized_end=7261
  _L4PORTRANGE._serialized_start=7488
  _L4PORTRANGE._serialized_end=7935
  _L4PORTRANGE_CHOICE._serialized_start=7778
  _L4PORTRANGE_CHOICE._serialized_end=7840
  _L4PORTRANGE_CHOICE_ENUM._serialized_start=7788
  _L4PORTRANGE_CHOICE_ENUM._serialized_end=7840
  _L4PORTRANGESINGLEVALUE._serialized_start=7938
  _L4PORTRANGESINGLEVALUE._serialized_end=8074
  _L4PORTRANGERANGE._serialized_start=8077
  _L4PORTRANGERANGE._serialized_end=8302
  _DATAFLOWFLOWPROFILEUDP._serialized_start=8304
  _DATAFLOWFLOWPROFILEUDP._serialized_end=8365
  _DATAFLOWWORKLOADITEM._serialized_start=8368
  _DATAFLOWWORKLOADITEM._serialized_end=9526
  _DATAFLOWWORKLOADITEM_CHOICE._serialized_start=9273
  _DATAFLOWWORKLOADITEM_CHOICE._serialized_end=9401
  _DATAFLOWWORKLOADITEM_CHOICE_ENUM._serialized_start=9283
  _DATAFLOWWORKLOADITEM_CHOICE_ENUM._serialized_end=9401
  _DATAFLOWSCATTERWORKLOAD._serialized_start=9529
  _DATAFLOWSCATTERWORKLOAD._serialized_end=9848
  _DATAFLOWBROADCASTWORKLOAD._serialized_start=9851
  _DATAFLOWBROADCASTWORKLOAD._serialized_end=10172
  _DATAFLOWGATHERWORKLOAD._serialized_start=10175
  _DATAFLOWGATHERWORKLOAD._serialized_end=10493
  _DATAFLOWALLREDUCEWORKLOAD._serialized_start=10496
  _DATAFLOWALLREDUCEWORKLOAD._serialized_end=10895
  _DATAFLOWALLREDUCEWORKLOAD_TYPE._serialized_start=10761
  _DATAFLOWALLREDUCEWORKLOAD_TYPE._serialized_end=10827
  _DATAFLOWALLREDUCEWORKLOAD_TYPE_ENUM._serialized_start=10769
  _DATAFLOWALLREDUCEWORKLOAD_TYPE_ENUM._serialized_end=10827
  _DATAFLOWALLTOALLWORKLOAD._serialized_start=10898
  _DATAFLOWALLTOALLWORKLOAD._serialized_end=11111
  _DATAFLOWCOMPUTEWORKLOAD._serialized_start=11114
  _DATAFLOWCOMPUTEWORKLOAD._serialized_end=11516
  _DATAFLOWCOMPUTEWORKLOAD_CHOICE._serialized_start=11406
  _DATAFLOWCOMPUTEWORKLOAD_CHOICE._serialized_end=11454
  _DATAFLOWCOMPUTEWORKLOAD_CHOICE_ENUM._serialized_start=11416
  _DATAFLOWCOMPUTEWORKLOAD_CHOICE_ENUM._serialized_end=11454
  _DATAFLOWSIMULATEDCOMPUTEWORKLOAD._serialized_start=11519
  _DATAFLOWSIMULATEDCOMPUTEWORKLOAD._serialized_end=11688
  _DATAFLOWLOOPWORKLOAD._serialized_start=11691
  _DATAFLOWLOOPWORKLOAD._serialized_end=11950
  _DATAFLOWHOSTMANAGEMENT._serialized_start=11953
  _DATAFLOWHOSTMANAGEMENT._serialized_end=12363
  _SETCONFIGREQUEST._serialized_start=12365
  _SETCONFIGREQUEST._serialized_end=12424
  _GETCONFIGREQUEST._serialized_start=12426
  _GETCONFIGREQUEST._serialized_end=12507
  _SETCONFIGRESPONSE._serialized_start=12510
  _SETCONFIGRESPONSE._serialized_end=12766
  _GETCONFIGRESPONSE._serialized_start=12769
  _GETCONFIGRESPONSE._serialized_end=13025
  _RUNEXPERIMENTREQUEST._serialized_start=13027
  _RUNEXPERIMENTREQUEST._serialized_end=13113
  _RUNEXPERIMENTRESPONSE._serialized_start=13116
  _RUNEXPERIMENTRESPONSE._serialized_end=13384
  _STARTREQUEST._serialized_start=13386
  _STARTREQUEST._serialized_end=13469
  _STARTRESPONSE._serialized_start=13472
  _STARTRESPONSE._serialized_end=13732
  _GETSTATUSREQUEST._serialized_start=13734
  _GETSTATUSREQUEST._serialized_end=13823
  _GETSTATUSRESPONSE._serialized_start=13826
  _GETSTATUSRESPONSE._serialized_end=14097
  _GETMETRICSREQUEST._serialized_start=14099
  _GETMETRICSREQUEST._serialized_end=14176
  _GETMETRICSRESPONSE._serialized_start=14179
  _GETMETRICSRESPONSE._serialized_end=14445
  _OPENAPI._serialized_start=14448
  _OPENAPI._serialized_end=15342
# @@protoc_insertion_point(module_scope)
